@@ -37,4 +37,4 @@ auc = function(truth, prob, positive, na_value = NaN, ...) {
 }
 
 #' @include measures.R
-add_measure(auc, "binary", 0, 1, FALSE)
+add_measure(auc, "Area Under the ROC Curve", "binary", 0, 1, FALSE)
