@@ -3,7 +3,7 @@
 #' @description
 #' Binary classification measure defined with \eqn{P} as [precision()] and \eqn{R} as
 #' [recall()] as \deqn{
-#'    (1 + \beta^2) \frac{PR}{(\beta^2 P) + R}.
+#'    (1 + \beta^2) \frac{P \cdot R}{(\beta^2 P) + R}.
 #' }{
 #'    (1 + beta^2) * (P*R) / ((beta^2 * P) + R).
 #' }
@@ -47,4 +47,4 @@ fbeta_cm = function(m, beta = 1, na_value = NaN) {
 }
 
 #' @include measures.R
-add_measure(fbeta, "binary", 0, 1, FALSE)
+add_measure(fbeta, "F-beta score", "binary", 0, 1, FALSE)
