@@ -34,5 +34,5 @@ tnr_cm = function(m, na_value = NaN) {
 specificity = tnr
 
 #' @include measures.R
-add_measure(tnr, "binary", 0, 1, FALSE)
-add_measure(specificity, "binary", 0, 1, FALSE)
+add_measure(tnr, "True Negative Rate", "binary", 0, 1, FALSE)
+add_measure(specificity, "Specificity", "binary", 0, 1, FALSE)
