@@ -12,16 +12,16 @@
 measures = new.env(parent = emptyenv())
 
 # adds items to registry
-add_measure = function(obj, type, lower, upper, minimize, groups = character()) {
+add_measure = function(obj, title, type, lower, upper, minimize) {
   id = deparse(substitute(obj))
 
   assign(id, list(
       id = id,
       type = assert_choice(type, c("binary", "classif", "regr")),
+      title = assert_string(title),
       lower = assert_number(lower),
       upper = assert_number(upper),
       predict_type = intersect(names(formals(obj)), c("response", "prob")),
-      minimize = assert_flag(minimize, na.ok = TRUE),
-      groups = assert_character(groups)
+      minimize = assert_flag(minimize, na.ok = TRUE)
   ), envir = measures)
 }
